Learn R Programming

MortCast (version 2.7-0)

kannisto.estimate: Kannisto Estimation

Description

Estimate the Kannisto parameters (Thatcher et al. 1998).

Usage

kannisto.estimate(mx, ages)

Arguments

mx

A vector of mortality rates.

ages

A vector of ages corresponding to mx. These can be indices of age groups or raw ages.

Value

List with the following components:

coefficients:

named vector with Kannisto coefficients \(c\) and \(d\).

fitted.values:

the fitted values

residuals:

input rates minus the fitted values

Details

Given the Kannisto equation \(logit(m_x) = \log(c) + dx\), the function estimates the \(c\) and \(d\) parameters using values of ages as the covariate \(x\).

References

Thatcher, A. R., Kannisto, V. and Vaupel, J. W. (1998). The Force of Mortality at Ages 80 to 120, volume 5 of Odense Monographs on Population Aging Series. Odense, Denmark: Odense University Press.

See Also

kannisto.predict, kannisto, cokannisto.estimate

Examples

Run this code
# NOT RUN {
data(mxM, package = "wpp2017")
mx <- subset(mxM, name == "Canada")[,"2010-2015"]
kannisto.estimate(mx[18:21], ages = 18:21)

# }

Run the code above in your browser using DataLab